<?php

namespace Drupal\w3_element_prohibitions\Resolver;

/**
 * Class ChainedProhibitionsResolver
 *
 * @package Drupal\w3_element_prohibitions\Resolver
 */
class ChainedProhibitionsResolver implements ChainedProhibitionsResolverInterface {

  /**
   * The resolvers.
   *
   * @var \Drupal\w3_element_prohibitions\Resolver\ProhibitionsResolverInterface[]
   */
  protected $resolvers = [];

  /**
   * Constructs a new ChainProhibitionsResolver object.
   *
   * @param \Drupal\w3_element_prohibitions\Resolver\ProhibitionsResolverInterface[] $resolvers
   *   The resolvers.
   */
  public function __construct(array $resolvers = []) {
    $this->resolvers = $resolvers;
  }

  /**
   * {@inheritdoc}
   */
  public function addResolver(ProhibitionsResolverInterface $resolver): void {
    $this->resolvers[] = $resolver;
  }

  /**
   * {@inheritdoc}
   */
  public function getResolvers(): array {
    return $this->resolvers;
  }

  /**
   * {@inheritdoc}
   */
  public function resolve(string $hook, array $element): ?string {
    foreach ($this->resolvers as $resolver) {
      $result = $resolver->resolve($hook, $element);
      if (!empty($result)) {
        return $result;
      }
    }

    return NULL;
  }

}
